@@ -24,7 +24,7 @@ import sys
 from pathlib import Path
 from enum import Enum
 from typing import Any
-from importlib.metadata import files, PackageNotFoundError
+from importlib_metadata import files, PackageNotFoundError
 
 # local imports
 from .utils.appdirs import get_home_dir, get_conf_path, get_data_path
@@ -269,7 +269,7 @@ def get_command_path(dist: str, command: str) -> str:
     if dist_files:
         try:
             rel_path = next(p for p in dist_files if p.match(f"**/bin/{command}"))
-            path = rel_path.locate()
+            path = rel_path.locate()  # type: ignore[assignment] # returns PathLike
         except StopIteration:
             path = None
     else:
