@@ -7,16 +7,14 @@ from __future__ import annotations
 
 # system imports
 import os
-import time
 import errno
 import contextlib
-import functools
-from typing import Iterator, Union, TypeVar, Callable, Any, cast
+from typing import Iterator, Union, TypeVar, Callable, Any
 
 # external imports
 import requests
 from dropbox import files, sharing, users, async_, auth, common
-from dropbox import exceptions  # type: ignore
+from dropbox import exceptions
 from dropbox.stone_validators import ValidationError
 
 # local imports
@@ -58,7 +56,6 @@ __all__ = [
     "dropbox_to_maestral_error",
     "os_to_maestral_error",
     "convert_api_errors",
-    "retry_on_error",
 ]
 
 CONNECTION_ERRORS = (
@@ -89,7 +86,6 @@ def convert_api_errors(
     :param dbx_path: Dropbox path associated with the error.
     :param local_path: Local path associated with the error.
     """
-
     try:
         yield
     except (exceptions.DropboxException, ValidationError) as exc:
@@ -105,7 +101,7 @@ def convert_api_errors(
             # Can occur on macOS, see https://bugs.python.org/issue33450.
             raise DropboxConnectionError(
                 "Cannot connect to Dropbox",
-                "Please check you internet connection and try again later.",
+                "Please check your internet connection and try again later.",
             )
         else:
             raise os_to_maestral_error(exc, dbx_path, local_path)
@@ -123,7 +119,6 @@ def os_to_maestral_error(
     :param local_path: Local path associated with the error.
     :returns: Converted exception.
     """
-
     title = "Could not sync file or folder"
     err_cls: type[MaestralApiError]
 
@@ -146,7 +141,6 @@ def os_to_maestral_error(
         title = "Could not create local folder"
         text = "The given path refers to a file."
     elif exc.errno == errno.ENAMETOOLONG:
-
         err_cls = PathError  # subclass of SyncError
         title = "Could not create local file"
 
@@ -211,14 +205,12 @@ def dropbox_to_maestral_error(
     :param local_path: Local path associated with the error.
     :returns: Converted exception.
     """
-
     title = "An unexpected error occurred"
     text = "Please contact the developer with the traceback information from the logs."
     err_cls = MaestralApiError
 
     # ---- Dropbox API Errors ----------------------------------------------------------
     if isinstance(exc, exceptions.ApiError):
-
         error = exc.error
 
         if isinstance(error, files.RelocationError):
@@ -423,9 +415,7 @@ def dropbox_to_maestral_error(
                 err_cls = CursorResetError
 
         elif isinstance(error, async_.PollError):
-
             title = "Could not get status of batch job"
-
             if error.is_internal_error():
                 text = (
                     "Something went wrong with the job on Dropbox’s end. Please "
@@ -439,17 +429,13 @@ def dropbox_to_maestral_error(
                 pass
 
         elif isinstance(error, files.ListRevisionsError):
-
             title = "Could not list file revisions"
-
             if error.is_path():
                 lookup_error = error.get_path()
                 text, err_cls = get_lookup_error_msg(lookup_error)
 
         elif isinstance(error, files.RestoreError):
-
             title = "Could not restore file"
-
             if error.is_invalid_revision():
                 text = "Invalid revision."
                 err_cls = NotFoundError
@@ -466,14 +452,12 @@ def dropbox_to_maestral_error(
 
         elif isinstance(error, files.GetMetadataError):
             title = "Could not get metadata"
-
             if error.is_path():
                 lookup_error = error.get_path()
                 text, err_cls = get_lookup_error_msg(lookup_error)
 
         elif isinstance(error, users.GetAccountError):
             title = "Could not get account info"
-
             if error.is_no_account():
                 text = (
                     "An account with the given Dropbox ID does not "
@@ -483,7 +467,6 @@ def dropbox_to_maestral_error(
 
         elif isinstance(error, sharing.CreateSharedLinkWithSettingsError):
             title = "Could not create shared link"
-
             if error.is_access_denied():
                 text = "You do not have access to create shared links for this path."
                 err_cls = InsufficientPermissionsError
@@ -506,7 +489,6 @@ def dropbox_to_maestral_error(
 
         elif isinstance(error, sharing.RevokeSharedLinkError):
             title = "Could not revoke shared link"
-
             if error.is_shared_link_malformed():
                 text = "The shared link is malformed."
                 err_cls = SharedLinkError
@@ -522,7 +504,6 @@ def dropbox_to_maestral_error(
 
         elif isinstance(error, sharing.ListSharedLinksError):
             title = "Could not list shared links"
-
             if error.is_path():
                 lookup_error = error.get_path()
                 text, err_cls = get_lookup_error_msg(lookup_error)
@@ -640,7 +621,6 @@ def dropbox_to_maestral_error(
 
 
 def get_write_error_msg(write_error: files.WriteError) -> tuple[str, type[SyncError]]:
-
     text = ""
     err_cls = SyncError
 
@@ -678,8 +658,8 @@ def get_write_error_msg(write_error: files.WriteError) -> tuple[str, type[SyncEr
         err_cls = InsufficientSpaceError
     elif write_error.is_malformed_path():
         text = (
-            "The destination path is invalid. Paths may not end with a slash or "
-            "whitespace."
+            "The destination path contains incompatible characters. Paths may not end "
+            "with a slash or whitespace or contain some characters such as emojis."
         )
         err_cls = PathError
     elif write_error.is_no_write_permission():
@@ -701,7 +681,6 @@ def get_write_error_msg(write_error: files.WriteError) -> tuple[str, type[SyncEr
 def get_lookup_error_msg(
     lookup_error: files.LookupError,
 ) -> tuple[str, type[SyncError]]:
-
     err_cls = SyncError
 
     if lookup_error.is_malformed_path():
@@ -738,7 +717,6 @@ def get_lookup_error_msg(
 def get_session_lookup_error_msg(
     session_lookup_error: files.UploadSessionLookupError,
 ) -> tuple[str, type[SyncError]]:
-
     err_cls = SyncError
 
     if session_lookup_error.is_closed():
@@ -773,7 +751,6 @@ def get_session_lookup_error_msg(
 def get_bad_path_error_msg(
     path_error: sharing.SharePathError,
 ) -> tuple[str, type[SyncError]]:
-
     err_cls = SyncError
 
     if path_error.is_is_file():
@@ -817,39 +794,3 @@ def get_bad_path_error_msg(
         text = "An unexpected error occurred. Please try again later."
 
     return text, err_cls
-
-
-# ==== decorator to retry on errors ====================================================
-
-
-def retry_on_error(
-    error_cls: type[Exception], max_retries: int, backoff: int = 0
-) -> Callable[[FT], FT]:
-    """
-    A decorator to retry a function call if a specified exception occurs.
-
-    :param error_cls: Error type to catch.
-    :param max_retries: Maximum number of retries.
-    :param backoff: Time in seconds to sleep before retry.
-    """
-
-    def decorator(func: FT) -> FT:
-        @functools.wraps(func)
-        def wrapper(*args, **kwargs):
-            tries = 0
-
-            while True:
-                try:
-                    return func(*args, **kwargs)
-                except error_cls as exc:
-
-                    if tries < max_retries:
-                        tries += 1
-                        if backoff > 0:
-                            time.sleep(backoff)
-                    else:
-                        raise exc
-
-        return cast(FT, wrapper)
-
-    return decorator
