@@ -5,7 +5,6 @@ This module is responsible for authorization and token store in the system keyri
 from __future__ import annotations
 
 # system imports
-import enum
 from threading import RLock
 
 # external imports
@@ -20,14 +19,14 @@ from keyring.core import load_keyring
 from keyring.errors import KeyringLocked, PasswordDeleteError, InitError
 
 # local imports
-from .config import MaestralConfig, MaestralState
+from .config import MaestralConfig
 from .exceptions import KeyringAccessError
 from .cli import output
 from .utils import exc_info_tuple
 from .logging import scoped_logger
 
 
-__all__ = ["CredentialStorage", "TokenType"]
+__all__ = ["CredentialStorage"]
 
 
 supported_keyring_backends = (
@@ -47,16 +46,6 @@ CONNECTION_ERRORS = (
 )
 
 
-class TokenType(enum.Enum):
-    """Enumeration of token types"""
-
-    Offline = "offline"
-    """Long-lived refresh-token to generate short-lived access tokens"""
-
-    Legacy = "legacy"
-    """Long-lived access token"""
-
-
 class CredentialStorage:
     """Provides a threadsafe interface to store credentials in a system keyring
 
@@ -81,12 +70,10 @@ class CredentialStorage:
     _lock = RLock()
 
     def __init__(self, config_name: str) -> None:
-
         self._config_name = config_name
         self._logger = scoped_logger(config_name, __name__)
 
         self._conf = MaestralConfig(config_name)
-        self._state = MaestralState(config_name)
 
         # defer keyring access until token requested by user
         self._token: str | None = None
@@ -109,7 +96,6 @@ class CredentialStorage:
 
         :param ring: Keyring backend to use.
         """
-
         if not ring:
             self._conf.set("auth", "keyring", "automatic")
         else:
@@ -123,7 +109,6 @@ class CredentialStorage:
 
     def _keyring_from_config(self) -> KeyringBackend | None:
         """Initialise keyring specified in config."""
-
         keyring_class: str = self._conf.get("auth", "keyring").strip()
 
         if keyring_class == "automatic":
@@ -145,7 +130,6 @@ class CredentialStorage:
         """Find and initialise the most secure of the available and supported keyring
         backends.
         """
-
         import keyring.backends
 
         # Get preferred keyring backends for platform.
@@ -168,37 +152,18 @@ class CredentialStorage:
         instance properties."""
         return self._loaded
 
-    @property
-    def token_type(self) -> TokenType | None:
-        """The type of token (read only). If 'legacy', we have a long-lived access
-        token. If 'offline', we have a long-lived refresh token which can be used to
-        generate new short-lived access tokens."""
-
-        with self._lock:
-            token_access_type = self._state.get("auth", "token_access_type")
-
-            if token_access_type == "offline":
-                return TokenType.Offline
-            elif token_access_type == "legacy":
-                return TokenType.Legacy
-
-            return None
-
     @property
     def token(self) -> str | None:
         """The saved token (read only). This call will block until the keyring is
         unlocked."""
-
         with self._lock:
             if not self._loaded:
                 self.load_creds()
-
             return self._token
 
     @property
     def account_id(self) -> str | None:
         """The saved account id (read only)."""
-
         with self._lock:
             return self._conf.get("auth", "account_id") or None
 
@@ -206,12 +171,11 @@ class CredentialStorage:
         """
         Loads auth token from system keyring. This will be called automatically when
         accessing the :attr:`token` property. This call will block until the keyring is
-        unlocked.
+        unlocked or unlocking is declined by the user.
 
         :raises KeyringAccessError: if the system keyring is locked or otherwise cannot
             be accessed (for example if the app bundle signature has been invalidated).
         """
-
         if not (self.keyring and self.account_id):
             return
 
@@ -220,9 +184,7 @@ class CredentialStorage:
         accessor = self._get_accessor(self.account_id)
 
         try:
-
             token = self.keyring.get_password("Maestral", accessor)
-
         except (KeyringLocked, InitError):
             title = "Could not load auth token"
             msg = (
@@ -242,18 +204,15 @@ class CredentialStorage:
             self._token = token
             self._loaded = True
 
-    def save_creds(self, account_id: str, token: str, token_type: TokenType) -> None:
+    def save_creds(self, account_id: str, token: str) -> None:
         """
         Saves the auth token to system keyring. Falls back to plain text storage if the
         user denies access to keyring.
 
         :param account_id: The account ID.
         :param token: The access token.
-        :param token_type: The type of access token.
         """
-
         with self._lock:
-
             if self._keyring:
                 keyring = self._keyring
             else:
@@ -271,7 +230,6 @@ class CredentialStorage:
             self.set_keyring_backend(keyring)
 
             self._conf.set("auth", "account_id", account_id)
-            self._state.set("auth", "token_access_type", token_type.value)
 
             self._token = token
             self._loaded = True
@@ -288,11 +246,8 @@ class CredentialStorage:
         :raises KeyringAccessError: if the system keyring is locked or otherwise cannot
             be accessed (for example if the app bundle signature has been invalidated).
         """
-
         with self._lock:
-
             if self.keyring and self.account_id:
-
                 accessor = self._get_accessor(self.account_id)
 
                 try:
@@ -320,7 +275,7 @@ class CredentialStorage:
             self.set_keyring_backend(None)
 
             self._conf.set("auth", "account_id", "")
-            self._state.set("auth", "token_access_type", "")
+            self._conf.set("auth", "token_access_type", "")
             self._token = None
             self._loaded = False
 
