@@ -1,13 +1,17 @@
-# -*- coding: utf-8 -*-
 """
 This module handles desktop notifications It uses the
 `desktop-notifier <https://desktop-notifier.readthedocs.io/en/latest/>`_ package as a
 backend for cross-platform desktop notifications.
 """
 
+from __future__ import annotations
+
 # system imports
+import logging
 import time
-from typing import Optional, Dict, Callable
+import asyncio
+from asyncio import AbstractEventLoop
+from typing import Callable, Any, cast
 
 # external imports
 from desktop_notifier import DesktopNotifier, Urgency, Button
@@ -27,6 +31,9 @@ __all__ = [
     "MaestralDesktopNotifier",
 ]
 
+logger = logging.getLogger("desktop_notifier")
+logger.setLevel(logging.ERROR)
+
 _desktop_notifier = DesktopNotifier(
     app_name=APP_NAME,
     app_icon=APP_ICON_PATH.as_uri(),
@@ -65,7 +72,6 @@ def level_number_to_name(number: int) -> str:
     :param number: Level number.
     :returns: Level name.
     """
-
     try:
         return _level_to_name[number]
     except KeyError:
@@ -79,7 +85,6 @@ def level_name_to_number(name: str) -> int:
     :param name: Level name.
     :returns: Level number.
     """
-
     try:
         return _name_to_level[name]
     except KeyError:
@@ -89,21 +94,24 @@ def level_name_to_number(name: str) -> int:
 class MaestralDesktopNotifier:
     """Desktop notification emitter for Maestral
 
-    Desktop notifier with snooze functionality and variable notification levels.
+    Desktop notifier with snooze functionality and variable notification levels. Must
+    be instantiated in the main thread.
 
     :param config_name: Config name. This is used to access notification settings for
         the daemon.
+    :param event_loop: Event loop to use to send notifications and receive callbacks.
     """
 
-    def __init__(self, config_name: str) -> None:
+    def __init__(self, config_name: str, event_loop: AbstractEventLoop) -> None:
         self._conf = MaestralConfig(config_name)
         self._snooze = 0.0
+        self._loop = event_loop
 
     @property
     def notify_level(self) -> int:
         """Custom notification level. Notifications with a lower level will be
         discarded."""
-        return self._conf.get("app", "notification_level")
+        return cast(int, self._conf.get("app", "notification_level"))
 
     @notify_level.setter
     def notify_level(self, level: int) -> None:
@@ -125,11 +133,12 @@ class MaestralDesktopNotifier:
         title: str,
         message: str,
         level: int = FILECHANGE,
-        on_click: Optional[Callable] = None,
-        actions: Optional[Dict[str, Callable]] = None,
+        on_click: Callable[[], Any] | None = None,
+        actions: dict[str, Callable[[], Any]] | None = None,
     ) -> None:
         """
-        Sends a desktop notification.
+        Sends a desktop notification. This will schedule a notification task in the
+        asyncio loop of the thread where :class:`DesktopNotifier` was instantiated.
 
         :param title: Notification title.
         :param message: Notification message.
@@ -139,22 +148,25 @@ class MaestralDesktopNotifier:
         :param actions: A dictionary with button names and callbacks for the
             notification.
         """
+        if level < self.notify_level:
+            return
 
-        snoozed = self.snoozed and level <= FILECHANGE
+        if self.snoozed and level <= FILECHANGE:
+            return
 
-        if level >= self.notify_level and not snoozed:
+        urgency = Urgency.Critical if level >= ERROR else Urgency.Normal
 
-            urgency = Urgency.Critical if level >= ERROR else Urgency.Normal
+        if actions:
+            buttons = [Button(name, handler) for name, handler in actions.items()]
+        else:
+            buttons = []
 
-            if actions:
-                buttons = [Button(name, handler) for name, handler in actions.items()]
-            else:
-                buttons = []
+        coro = _desktop_notifier.send(
+            title=title,
+            message=message,
+            urgency=urgency,
+            on_clicked=on_click,
+            buttons=buttons,
+        )
 
-            _desktop_notifier.send_sync(
-                title=title,
-                message=message,
-                urgency=urgency,
-                on_clicked=on_click,
-                buttons=buttons,
-            )
+        asyncio.run_coroutine_threadsafe(coro, self._loop)
