@@ -14,8 +14,12 @@ import platform
 from stat import S_ISDIR
 from typing import List, Optional, Tuple, Callable, Iterator, Iterable, Union
 
+# third party imports
+import xattr
+
 # local imports
 from .hashing import DropboxContentHasher
+from ..constants import IS_LINUX
 
 F_GETPATH = 50
 
@@ -355,7 +359,8 @@ def move(
     src_path: str,
     dest_path: str,
     raise_error: bool = False,
-    preserve_dest_permissions: bool = False,
+    keep_target_permissions: bool = False,
+    keep_target_xattrs: bool = False,
 ) -> Optional[OSError]:
     """
     Moves a file or folder from ``src_path`` to ``dest_path``. If either the source or
@@ -369,18 +374,30 @@ def move(
         by the move. Any existing **empty** folder will be replaced if the source is
         also a folder.
     :param raise_error: Whether to raise errors or return them.
-    :param preserve_dest_permissions: Whether to apply the permissions of the source
-        path to the destination path. Permissions will not be set recursively.
+    :param keep_target_permissions: Whether to preserve the permissions of a file at the
+        destination, if any.
+    :param keep_target_xattrs: Whether to preserve the extended attributes of a file at
+        the destination, if any.
     :returns: Any caught exception during the move.
     """
     err: Optional[OSError] = None
-    orig_mode: Optional[int] = None
 
-    if preserve_dest_permissions:
-        # save dest permissions
+    if keep_target_permissions:
         try:
-            orig_mode = os.lstat(dest_path).st_mode & 0o777
-        except FileNotFoundError:
+            dest_mode = os.lstat(dest_path).st_mode & 0o777
+            follow_symlinks = os.chmod not in os.supports_follow_symlinks
+            os.chmod(src_path, dest_mode, follow_symlinks=follow_symlinks)
+        except (FileNotFoundError, NotADirectoryError):
+            pass
+
+    if keep_target_xattrs:
+        try:
+            dest_attrs = xattr.xattr(dest_path)
+            for key, value in dest_attrs.iteritems():
+                if key.startswith('user.') or not IS_LINUX:
+                    xattr.setxattr(src_path, key, value)
+        except OSError:
+            # Fail gracefully if extended attributes are not supported by the system.
             pass
 
     try:
@@ -390,16 +407,6 @@ def move(
         pass
     except OSError as exc:
         err = exc
-    else:
-        if orig_mode:
-            # reapply dest permissions
-            try:
-                if os.chmod in os.supports_follow_symlinks:
-                    os.chmod(dest_path, orig_mode, follow_symlinks=False)
-                else:
-                    os.chmod(dest_path, orig_mode)
-            except OSError:
-                pass
 
     if raise_error and err:
         raise err
@@ -530,36 +537,32 @@ def opener_no_symlink(path: _AnyPath, flags: int) -> int:
     return os.open(path, flags=flags)
 
 
-def _get_stats_no_symlink(path: _AnyPath) -> Optional[os.stat_result]:
-    try:
-        return os.lstat(path)
-    except (FileNotFoundError, NotADirectoryError):
-        return None
-
-
 def exists(path: _AnyPath) -> bool:
     """Returns whether an item exists at the path. Returns True for symlinks."""
-    return _get_stats_no_symlink(path) is not None
+    try:
+        os.lstat(path)
+    except (FileNotFoundError, NotADirectoryError):
+        return False
+    else:
+        return True
 
 
 def isfile(path: _AnyPath) -> bool:
     """Returns whether a file exists at the path. Returns True for symlinks."""
-    stat = _get_stats_no_symlink(path)
-
-    if stat is None:
-        return False
-    else:
+    try:
+        stat = os.lstat(path)
         return not S_ISDIR(stat.st_mode)
+    except (FileNotFoundError, NotADirectoryError):
+        return False
 
 
 def isdir(path: _AnyPath) -> bool:
     """Returns whether a folder exists at the path. Returns False for symlinks."""
-    stat = _get_stats_no_symlink(path)
-
-    if stat is None:
-        return False
-    else:
+    try:
+        stat = os.lstat(path)
         return S_ISDIR(stat.st_mode)
+    except (FileNotFoundError, NotADirectoryError):
+        return False
 
 
 def getsize(path: _AnyPath) -> int:
