@@ -7,6 +7,7 @@ import os.path as osp
 import time
 import shutil
 import timeit
+from datetime import datetime, timezone
 from typing import Union, Mapping, TypeVar, cast
 
 import pytest
@@ -114,6 +115,21 @@ def test_file_lifecycle(m: Maestral, name: str) -> None:
     assert_synced(m, {})
 
 
+def test_remote_mtime_applied(m: Maestral) -> None:
+    dbx_path = "/test.txt"
+    local_path = m.to_local_path(dbx_path)
+    mtime = datetime.fromisoformat("2019-12-04")
+    m.client.dbx.files_upload(
+        "content", dbx_path, mode=files.WriteMode.overwrite, client_modified=mtime
+    )
+
+    wait_for_idle(m)
+
+    local_mtime = os.stat(local_path).st_mtime
+    remote_mtime = mtime.replace(tzinfo=timezone.utc).timestamp()
+    assert local_mtime == remote_mtime
+
+
 def test_folder_tree_local(m: Maestral) -> None:
     """Tests the upload sync of a nested local folder structure."""
 
@@ -415,7 +431,7 @@ def test_excluded_folder_cleared_on_deletion(m: Maestral) -> None:
     wait_for_idle(m)
 
     # Exclude the folder from sync.
-    m.exclude_item(dbx_path)
+    m.exclude_items(dbx_path)
     wait_for_idle(m)
 
     assert normalize(dbx_path) in m.excluded_items
@@ -793,7 +809,7 @@ def test_selective_sync_conflict(m: Maestral) -> None:
     wait_for_idle(m)
 
     # exclude 'folder' from sync
-    m.exclude_item("/folder")
+    m.exclude_items("/folder")
     wait_for_idle(m)
 
     assert_synced(m, {})
